dhcpkit.ipv6.option_handlers.fixed_assignment module
====================================================

.. automodule:: dhcpkit.ipv6.option_handlers.fixed_assignment
    :members:
    :undoc-members:
    :show-inheritance:
